@@ -2,7 +2,16 @@ import optparse
 
 from autojenkins import Jenkins
 
+COLOR_MEANING = { 
+    'blue': ('1;34', 'SUCCESS'), 
+    'red': ('1;31', 'FAILED'), 
+    'yellow': ('1;33', 'UNSTABLE'), 
+    'aborted': ('1;37', 'ABORTED'),
+    'disabled': ('0;37', 'DISABLED'),
+    'grey': ('1;37', 'NOT BUILT'),
+}
 
+ 
 def create_opts_parser(command, params="[jobname] [options]"):
     """
     Create parser for command-line options
@@ -51,23 +60,27 @@ def delete_job(host, jobname):
     response = jenkins.delete(jobname)
     print('Status: {0}'.format(response.status_code))
 
-def list_jobs(host):
+
+def list_jobs(host, color=True):
     """
     List all jobs
     """
-    COLOR = "\033[{0}m"
-    COLORCODE = { 
-        'blue': '1;34', 
-        'red': '1;31', 
-        'yellow': '1;33', 
-        'aborted': '1;37',
-        'disabled': '0;37',
-        'grey': '1;37',
-    }
-
+    if color:
+        FORMAT = "\033[{0}m{1}\033[0m"
+        position = 0
+    else:
+        FORMAT = "{0:<10} {1}"
+        position = 1
     print ("All jobs in {0}".format(host))
     jenkins = Jenkins(host)
     jobs = jenkins.all_jobs()
     for name, color in jobs:
-        print(COLOR.format(COLORCODE[color.split('_')[0]]) + name)
+        if '_' in color:
+            color = color.split('_')[0]
+            building = True
+        else:
+            building = False
+        prefix = '* ' if building else '  '
+        out = COLOR_MEANING[color][position]
+        print(prefix + FORMAT.format(out, name))
 
